#!/usr/bin/env python3
# -----------------------------------------------------------------
# Improved representation of clouds in the atmospheric component
# LMDZ6A of the IPSL Earth system model IPSL-CM6A
# J.-B. Madeleine et al. - 2020
# Journal of Advances in Modeling Earth Systems
# 
# Source Codes and supporting files
# Figure 8, left column
# -----------------------------------------------------------------

import netCDF4
from pylab import *
import numpy as np

# LMDZ 5A
ncfile="data/LmdzOrAPctrl_SE_1980_1999_1M_histmth_radTOA_144x90.nc"
ncgcm = netCDF4.Dataset(ncfile)
SWdnTOA = np.nanmean(np.nanmean(ncgcm.variables['SWdnTOA'][:],axis=0),axis=1)
SWdnTOAclr = np.nanmean(np.nanmean(ncgcm.variables['SWdnTOAclr'][:],axis=0),axis=1)
SWupTOA = np.nanmean(np.nanmean(ncgcm.variables['SWupTOA'][:],axis=0),axis=1)
SWupTOAclr = np.nanmean(np.nanmean(ncgcm.variables['SWupTOAclr'][:],axis=0),axis=1)
topl = np.nanmean(np.nanmean(ncgcm.variables['topl'][:],axis=0),axis=1)
topl0 = np.nanmean(np.nanmean(ncgcm.variables['topl0'][:],axis=0),axis=1)
swgcm5A = (SWdnTOA - SWupTOA) - (SWdnTOAclr - SWupTOAclr)
lwgcm5A = topl0 - topl
totgcm5A = swgcm5A + lwgcm5A

lat = ncgcm.variables['lat'][:]

# LMDZ 6A
ncfile="data/LmdzOr6Actrl_SE_1980_1999_1M_histmth_radTOA_144x90.nc"
ncgcm = netCDF4.Dataset(ncfile)
SWdnTOA = np.nanmean(np.nanmean(ncgcm.variables['SWdnTOA'][:],axis=0),axis=1)
SWdnTOAclr = np.nanmean(np.nanmean(ncgcm.variables['SWdnTOAclr'][:],axis=0),axis=1)
SWupTOA = np.nanmean(np.nanmean(ncgcm.variables['SWupTOA'][:],axis=0),axis=1)
SWupTOAclr = np.nanmean(np.nanmean(ncgcm.variables['SWupTOAclr'][:],axis=0),axis=1)
topl = np.nanmean(np.nanmean(ncgcm.variables['topl'][:],axis=0),axis=1)
topl0 = np.nanmean(np.nanmean(ncgcm.variables['topl0'][:],axis=0),axis=1)
swgcm6A = (SWdnTOA - SWupTOA) - (SWdnTOAclr - SWupTOAclr)
lwgcm6A = topl0 - topl
totgcm6A = swgcm6A + lwgcm6A

# OBS
ncfile='data/rstcre_CERES_000001-000012_ac_144x90.nc'
ncobs = netCDF4.Dataset(ncfile)
swobs = np.nanmean(np.nanmean(ncobs.variables['rstcre'][:],axis=0),axis=1)
ncfile='data/rltcre_CERES_000001-000012_ac_144x90.nc'
ncobs = netCDF4.Dataset(ncfile)
lwobs = np.nanmean(np.nanmean(ncobs.variables['rltcre'][:],axis=0),axis=1)
totobs = swobs + lwobs

# -----------------------------------------------------------------------------

fig, ax = plt.subplots(3)

ax[0].plot(lat, swobs, '0.7', linewidth=5.0,linestyle='-',label='OBS')
ax[0].plot(lat, swgcm5A, 'k', linewidth=2.0,linestyle='-',label='LMDZ5A')
ax[0].plot(lat, swgcm6A, 'r', linewidth=2.0,linestyle='-',label='LMDZ6A')
ax[0].set_ylabel(r"SW CRE TOA (W m$^{-2}$)")
ax[1].plot(lat, lwobs, '0.7', linewidth=5.0,linestyle='-')
ax[1].plot(lat, lwgcm5A, 'k', linewidth=2.0,linestyle='-')
ax[1].plot(lat, lwgcm6A, 'r', linewidth=2.0,linestyle='-')
ax[1].set_ylabel(r"LW CRE TOA (W m$^{-2}$)")
ax[2].plot(lat, totobs, '0.7', linewidth=5.0,linestyle='-')
ax[2].plot(lat, totgcm5A, 'k', linewidth=2.0,linestyle='-')
ax[2].plot(lat, totgcm6A, 'r', linewidth=2.0,linestyle='-')
ax[2].set_ylabel(r"Total CRE TOA (W m$^{-2}$)")

for ax in ax.flat:
    ax.grid(linestyle='--', linewidth=1)
    ax.set_xlim(xmin=-90,xmax=90)

fig.legend(loc=(0.7, 0.9))
plt.xlabel(r"Latitude")
plt.show()

# -----------------------------------------------------------------------------